@@ -778,6 +778,10 @@ def neighbours(graph, var):
 
 # get the edges of a graph
 def edges(graph):
+    if type(graph) is str:
+        graph = from_bnlearn(graph)
+    elif type(graph) is not dict:
+        raise Exception('The format of the input graph is invalid.')
     edge = pandas.DataFrame(columns=['from', 'to', 'type'])
     for var in graph:
         for par in parents(graph, var):
